@@ -3,15 +3,18 @@ package File::Rename;
 use strict;
 BEGIN { eval { require warnings; warnings->import } }
 
+require Exporter;
+our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( rename );
-our $VERSION = '1.90_1';
+
+our $VERSION = '1.90_2';
 
 sub import {
-    require Exporter;
-    our @ISA = qw(Exporter);
-    my( $pack ) = @_;
-    $pack->export_to_level(1, @_);
+    my $pack = shift;
+    my($args, $config) = &_config;  # sees @_
+    $pack->export_to_level(1, $pack, @$args);
     require File::Rename::Options;
+    File::Rename::Options->import(@$config);
 }
 
 sub rename_files {
@@ -126,6 +129,21 @@ sub _default {
     $$ref = { verbose => $verbose }
 }
 
+sub _config {
+    # copied from GetOpt::Long::import
+    my @syms = ();              # symbols to import
+    my @config = ();            # configuration
+    my $dest = \@syms;          # symbols first
+    for ( @_ ) {
+        if ( $_ eq ':config' ) {
+            $dest = \@config;   # config next
+            next;
+        }
+        push(@$dest, $_);       # push
+    }
+    return (\@syms, \@config);
+}
+    
 1;
 
 __END__
