@@ -5,17 +5,21 @@ BEGIN { eval { require warnings; warnings->import } }
 
 use Getopt::Long ();
 
-use vars qw($VERSION);
-$VERSION = '1.90';
+our $VERSION = '1.90';
+our $IMPORTED;
 
 sub import {
     my $pack = shift;
-   my @config = qw(
+    if( $IMPORTED++ ) { 
+        require Carp;
+        Carp::cluck("$pack->import() called twice");
+    }
+    my @config = qw(
       posix_default
       no_ignore_case
-)  ;
-   push @config, @_;
-   eval{ Getopt::Long::Configure(@config); 1; }
+    );
+    push @config, @_;
+    eval{ Getopt::Long::Configure(@config); 1; }
         or do { require Carp; Carp::carp($@) };
 }
 
@@ -89,6 +93,8 @@ File::Rename::Options - Option processing for File::Rename
     my $options = File::Rename::Options::GetOptions()
         or pod2usage;
 
+    use File::Rename::Options qw(no_require_order);
+
 =head1 DESCRIPTION
 
 =over 4
@@ -128,7 +134,7 @@ Returns C<undef> when there is an error in the options.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018 by Robin Barker
+Copyright (C) 2018, 2022 by Robin Barker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
